@@ -5,6 +5,7 @@ __all__ = [
     'ExcludeTestException',
     'InvalidTestConfigurationException',
     'IrrelevantTestException',
+    'TransientTestError',
 ]
 
 
@@ -61,7 +62,6 @@ class BrokenTestException(RichSkipTestException):
     in the project's issue tracker. This must be included in the exception
     as a separate field.
     """
-    
     def __init__(self, item_number, reason):
         super(BrokenTestException, self).__init__(reason)
         
@@ -100,6 +100,10 @@ class InvalidTestConfigurationException(RichSkipTestException):
     has not been supplied by the user. 
     
     This situation should be considered a test failure.
+    
+    @see IrrelevantTestException: Some configuration problems simply mean that
+        a test should be skipped because it is not relevant for the current
+        system.
     """
     pass
 
@@ -111,3 +115,13 @@ class IrrelevantTestException(RichSkipTestException):
     under Microsoft Windows.
     """
     pass
+
+
+class TransientTestError(RichSkipTestException):
+    """A test failed due to a transient error outside the test environment.
+    
+    For example, this might be used when there is an issue with network
+    connectivity, or when a 3rd party webservices server is temporarily
+    unavailable.
+    """
+    pass
\ No newline at end of file
